# pso_plot
PSO Plotting Utils

## Installation
```bash
```bash
pip install pso_plot
``````
## Usage
```python
```python
import matplotlib.pyplot as plt
import psoplot

plt.style.use("psoplot.aanda_publication")

# [Your plotting code here]
``````
